@@ -153,6 +153,8 @@ g_mmrm_diagnostic <- function(object,
 #' @param titles (`character`)\cr with elements `estimates` and `contrasts` containing the plot titles.
 #' @param xlab (`string`)\cr the x axis label.
 #' @param ylab (`string`)\cr the y axis label.
+#' @param xlimits (`numeric`)\cr x axis limits.
+#' @param ylimits (`numeric`)\cr y axis limits.
 #' @param width (`numeric`)\cr width of the error bars.
 #' @param show_pval (`flag`)\cr should the p-values for the differences of
 #'   LS means vs. control be displayed (not default)?
@@ -273,6 +275,8 @@ g_mmrm_lsmeans <-
            ),
            xlab = object$labels$visit,
            ylab = paste0("Estimates with ", round(object$conf_level * 100), "% CIs"),
+           xlimits = NULL,
+           ylimits = NULL,
            width = 0.6,
            show_pval = TRUE,
            show_lines = FALSE,
@@ -437,7 +441,8 @@ g_mmrm_lsmeans <-
         nrow = length(select),
         scales = "free_y", # Since estimates and contrasts need to have different y scales.
         labeller = ggplot2::as_labeller(titles)
-      )
+      ) +
+      ggplot2::coord_cartesian(ylim = ylimits, xlim = xlimits)
     if (show_lines) {
       result <- result +
         ggplot2::geom_line(position = pd)
